==> dotnet9_9.0.112-9.0.11.orig.tar.xz: src/roslyn/src/Analyzers/CSharp/Tests/NewLines/ConstructorInitializerPlacement/ConstructorInitializerPlacementTests.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

using System.Threading.Tasks;
using Microsoft.CodeAnalysis.CodeStyle;
using Microsoft.CodeAnalysis.CSharp.CodeStyle;
using Microsoft.CodeAnalysis.CSharp.NewLines.ConstructorInitializerPlacement;
using Microsoft.CodeAnalysis.Editor.UnitTests.CodeActions;
using Xunit;

namespace Microsoft.CodeAnalysis.Editor.CSharp.UnitTests.NewLines.ConstructorInitializerPlacement;

using Verify = CSharpCodeFixVerifier<
    ConstructorInitializerPlacementDiagnosticAnalyzer,
    ConstructorInitializerPlacementCodeFixProvider>;

public class ConstructorInitializerPlacementTests
{
    [Fact]
    public async Task TestNotWithOptionOff()
    {
        var code =
            """
            class C
            {
                public C() :
                    base()
                {
                }
            }
            """;

        await new Verify.Test
        {
            TestCode = code,
            FixedCode = code,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.TrueWithSilentEnforcement } }
        }.RunAsync();
    }

    [Fact]
    public async Task TestSimpleCase()
    {
        var code =
            """
            class C
            {
                public C() [|:|]
                    base()
                {
                }
            }
            """;

        var fixedCode =
            """
            class C
            {
                public C()
                    : base()
                {
                }
            }
            """;

        await new Verify.Test
        {
            TestCode = code,
            FixedCode = fixedCode,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();
    }

    [Fact]
    public async Task TestNotOnSameLine1()
    {
        var code =
            """
            class C
            {
                public C() : base()
                {
                }
            }
            """;

        await new Verify.Test
        {
            TestCode = code,
            FixedCode = code,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();
    }

    [Fact]
    public async Task TestNotOnSameLine2()
    {
        var code =
            """
            class C
            {
                public C()
                    : base()
                {
                }
            }
            """;

        await new Verify.Test
        {
            TestCode = code,
            FixedCode = code,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();
    }

    [Fact]
    public async Task TestNotWithColonTrailingComment()
    {
        var code =
            """
            class C
            {
                public C() : //comment
                    base()
                {
                }
            }
            """;

        await new Verify.Test
        {
            TestCode = code,
            FixedCode = code,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();
    }

    [Fact]
    public async Task TestWithCloseParenTrailingComment1()
    {
        var code =
            """
            class C
            {
                public C() /*comment*/ [|:|]
                    base()
                {
                }
            }
            """;
        var fixedCode =
            """
            class C
            {
                public C() /*comment*/ 
                    : base()
                {
                }
            }
            """;

        await new Verify.Test
        {
            TestCode = code,
            FixedCode = fixedCode,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();
    }

    [Fact]
    public async Task TestWithColonLeadingComment1()
    {
        var code =
            """
            class C
            {
                public C()
                    // comment
                    [|:|]
                    base()
                {
                }
            }
            """;
        var fixedCode =
            """
            class C
            {
                public C()
                    // comment
                    
                    : base()
                {
                }
            }
            """;

        await new Verify.Test
        {
            TestCode = code,
            FixedCode = fixedCode,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();
    }

    [Fact]
    public async Task TestWithLeadingComment()
    {
        var code =
            """
            class C
            {
                public C() [|:|]
                    // comment
                    base()
                {
                }
            }
            """;
        var fixedCode =
            """
            class C
            {
                public C()
                    // comment
                    : base()
                {
                }
            }
            """;

        await new Verify.Test
        {
            TestCode = code,
            FixedCode = fixedCode,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();
    }

    [Fact]
    public async Task TestWithLeadingDirective()
    {
        var code =
            """
            class C
            {
                public C() :
            #if true
                    base()
                {
                }
            #endif
            }
            """;

        await new Verify.Test
        {
            TestCode = code,
            FixedCode = code,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();
    }
}

==> dotnet10_10.0.100-10.0.0~rc1.orig.tar.xz: src/roslyn/src/Analyzers/CSharp/Tests/NewLines/ConstructorInitializerPlacement/ConstructorInitializerPlacementTests.cs <==
﻿// Licensed to the .NET Foundation under one or more agreements.
// The .NET Foundation licenses this file to you under the MIT license.
// See the LICENSE file in the project root for more information.

using System.Threading.Tasks;
using Microsoft.CodeAnalysis.CodeStyle;
using Microsoft.CodeAnalysis.CSharp.CodeStyle;
using Microsoft.CodeAnalysis.CSharp.NewLines.ConstructorInitializerPlacement;
using Microsoft.CodeAnalysis.Editor.UnitTests.CodeActions;
using Xunit;

namespace Microsoft.CodeAnalysis.Editor.CSharp.UnitTests.NewLines.ConstructorInitializerPlacement;

using Verify = CSharpCodeFixVerifier<
    ConstructorInitializerPlacementDiagnosticAnalyzer,
    ConstructorInitializerPlacementCodeFixProvider>;

public sealed class ConstructorInitializerPlacementTests
{
    [Fact]
    public Task TestNotWithOptionOff()
        => new Verify.Test
        {
            TestCode = """
            class C
            {
                public C() :
                    base()
                {
                }
            }
            """,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.TrueWithSilentEnforcement } }
        }.RunAsync();

    [Fact]
    public Task TestSimpleCase()
        => new Verify.Test
        {
            TestCode = """
            class C
            {
                public C() [|:|]
                    base()
                {
                }
            }
            """,
            FixedCode = """
            class C
            {
                public C()
                    : base()
                {
                }
            }
            """,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();

    [Fact]
    public Task TestNotOnSameLine1()
        => new Verify.Test
        {
            TestCode = """
            class C
            {
                public C() : base()
                {
                }
            }
            """,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();

    [Fact]
    public Task TestNotOnSameLine2()
        => new Verify.Test
        {
            TestCode = """
            class C
            {
                public C()
                    : base()
                {
                }
            }
            """,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();

    [Fact]
    public Task TestNotWithColonTrailingComment()
        => new Verify.Test
        {
            TestCode = """
            class C
            {
                public C() : //comment
                    base()
                {
                }
            }
            """,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();

    [Fact]
    public Task TestWithCloseParenTrailingComment1()
        => new Verify.Test
        {
            TestCode = """
            class C
            {
                public C() /*comment*/ [|:|]
                    base()
                {
                }
            }
            """,
            FixedCode = """
            class C
            {
                public C() /*comment*/ 
                    : base()
                {
                }
            }
            """,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();

    [Fact]
    public Task TestWithColonLeadingComment1()
        => new Verify.Test
        {
            TestCode = """
            class C
            {
                public C()
                    // comment
                    [|:|]
                    base()
                {
                }
            }
            """,
            FixedCode = """
            class C
            {
                public C()
                    // comment
                    
                    : base()
                {
                }
            }
            """,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();

    [Fact]
    public Task TestWithLeadingComment()
        => new Verify.Test
        {
            TestCode = """
            class C
            {
                public C() [|:|]
                    // comment
                    base()
                {
                }
            }
            """,
            FixedCode = """
            class C
            {
                public C()
                    // comment
                    : base()
                {
                }
            }
            """,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();

    [Fact]
    public Task TestWithLeadingDirective()
        => new Verify.Test
        {
            TestCode = """
            class C
            {
                public C() :
            #if true
                    base()
                {
                }
            #endif
            }
            """,
            Options = { { CSharpCodeStyleOptions.AllowBlankLineAfterColonInConstructorInitializer, CodeStyleOption2.FalseWithSuggestionEnforcement } }
        }.RunAsync();
}
